limit

package
v0.0.0-...-06a57de Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: GPL-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Limiter

type Limiter struct {
	// contains filtered or unexported fields
}

Limiter is for limiting the number of concurrent operations. This

func New

func New(limit int) *Limiter

New returns a new Limiter. The limit param is the maximum number of concurrent operations.

func (*Limiter) Begin

func (l *Limiter) Begin()

Begin an operation.

func (*Limiter) End

func (l *Limiter) End()

End the operation.

Jump to