Documentation
¶
Overview ¶
Package client provides Docker client initiatialisation functions.
Index ¶
- func CreateContext(contextName string) error
- func DeleteContext(name string) error
- func GetConfigNames(configs []swarm.Config) []string
- func GetConfigs(cl *client.Client, ctx context.Context, server string, fs filters.Args) ([]swarm.Config, error)
- func GetContext(contextName string) (contextStore.Metadata, error)
- func GetRegistryTags(img reference.Named) ([]string, error)
- func GetSecretNames(secrets []swarm.Secret) []string
- func GetVolumeNames(volumes []*volume.Volume) []string
- func GetVolumes(cl *client.Client, ctx context.Context, server string, fs filters.Args) ([]*volume.Volume, error)
- func New(serverName string, opts ...Opt) (*client.Client, error)
- func RemoveConfigs(cl *client.Client, ctx context.Context, configNames []string, force bool) error
- func RemoveVolumes(cl *client.Client, ctx context.Context, volumeNames []string, force bool, ...) error
- func StoreSecret(cl *client.Client, secretName, secretValue string) error
- type Conf
- type Context
- type Opt
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateContext ¶
CreateContext creates a new Docker context.
func DeleteContext ¶
func GetConfigNames ¶
func GetConfigs ¶
func GetContext ¶
func GetContext(contextName string) (contextStore.Metadata, error)
func GetRegistryTags ¶
GetRegistryTags retrieves all tags of an image from a container registry.
func GetSecretNames ¶
func GetVolumeNames ¶
func GetVolumes ¶
func New ¶
New initiates a new Docker client. New client connections are validated so that we ensure connections via SSH to the daemon can succeed. It takes into account that you may only want the local client and not communicate via SSH. For this use-case, please pass "default" as the serverName.
func RemoveConfigs ¶
func RemoveVolumes ¶
Types ¶
type Context ¶
type Context = contextStore.Metadata
Click to show internal directories.
Click to hide internal directories.